package main

import (
	"encoding/json"
	"fmt"
	"net/http"
	"os"
	"os/exec"
)

type cmdresult struct {
	Success bool   `json:"success"`
	Message string `json:"message"`
}

func homepage(w http.ResponseWriter, _ *http.Request) {
	fmt.Fprintf(w, "Go Home Simple REST API Server")
}

func getdate(w http.ResponseWriter, r *http.Request) {
	fmt.Printf("Processing request from %s: User-Agent: %s\n", r.RemoteAddr, r.UserAgent())

	out, err := exec.Command("date").Output()
	if err != nil {
		fmt.Fprintln(os.Stderr, "Cannot get current date:", err)
		http.Error(w, "Cannot get current date", http.StatusInternalServerError)
		return
	}

	result := cmdresult{
		Success: true,
		Message: "The date is " + string(out),
	}

	if err := json.NewEncoder(w).Encode(result); err != nil {
		fmt.Fprintln(os.Stderr, "Cannot write response:", err)
	}
}

func main() {
	http.HandleFunc("/", homepage)
	http.HandleFunc("/api/v1/getdate", getdate)

	fmt.Println("Starting API server on port 4000...")
	if err := http.ListenAndServe(":4000", nil); err != nil {
		fmt.Fprintln(os.Stderr, "Cannot start API server:", err)
		os.Exit(1)
	}
}
