import json
import machine
import network
import rp2
import socket
import time
import ubinascii
import urequests as requests
from machine import ADC
from config import params

# Set country code here - example = US
rp2.country('US')

wlan = network.WLAN(network.STA_IF)
wlan.active(True)

# Get SSID and WPA password from external config.py file
ssid = params['ssid']
wpapass = params['passwd']

wlan.connect(ssid, wpapass)

timeout = 10
while timeout > 0:
    if wlan.status() < 0 or wlan.status() >= 3:
        break
    timeout -= 1
    time.sleep(1)

wlan_status = wlan.status()

if wlan_status != 3:
    raise RuntimeError('Wi-Fi connection failed')
else:
    status = wlan.ifconfig()
    print('ip = ' + status[0])
    
# Create HTTP server allowing all inbound connections
addr = socket.getaddrinfo('0.0.0.0', 80)[0][-1]

soc = socket.socket()
soc.bind(addr)
soc.listen(1)

# Listen for inbound connections
while True:
    try:
        client, ipaddress = soc.accept()
        print('Client connected from', ipaddress)
        rec = client.recv(1024)

        tempsensor = ADC(machine.ADC.CORE_TEMP)
        convert = 3.3/(65535)
        tempvalue = tempsensor.read_u16()*convert
        celsius = 19-(tempvalue-0.706)/0.001721
        fahrenheit = round((celsius*1.8)+32, 2)
        celsius = round(celsius, 2)
        
        temp_Dict = {
            "tempC": celsius,
            "tempF": fahrenheit
        }

        json_output = json.dumps(temp_Dict)
        client.send('HTTP/1.0 200 OK\r\nContent-type: application/json \
                    \r\n\r\n')
        client.send(json_output)
        client.close()
        
    except OSError as e:
        client.close()
        print('Network connection closed')


